// -----------------------------------------------
// Shader programs for TextureBmpModern
// -----------------------------------------------
// Sets the position and color of a vertex.
//   This implementations just copies the position with no transformations.
//   It copies the color to "theColor" so that the fragment shader can access it.
#beginglsl VertexShader vertexShader_PosColorOnly
#version 330 core
layout (location = 0) in vec3 vertPos;	      // Position in attribute location 0 
layout (location = 1) in vec3 vertColor;     // Color in attribute location 1 
layout (location = 2) in vec2 vertTexCoord;  // Texture coordinates (s,t) in attribute location 2 

out vec3 theColor;					// output a color to the fragment shader
out vec2 theTexCoord;              // output texture coordinates to the fragment shader

void main()
{
   gl_Position = vec4(vertPos.x, vertPos.y, vertPos.z, 1.0);
   theColor = vertColor;
   theTexCoord = vertTexCoord; 
}
#endglsl

// Set a general color using a fragment shader. (A "fragment" is a "pixel".)
//    The color value is passed in, obtained from the color(s) on the vertice(s).
//    Color values range from 0.0 to 1.0.
//    First three values are Red/Green/Blue (RGB).
//    Fourth color value (alpha) is 1.0, meaning there is no transparency.
#beginglsl FragmentShader fragmentShader_ColorOnly
#version 330 core
in vec3 theColor;		// Color value came from the vertex shader (smoothed) 
in vec2 theTexCoord;	// Texture coordinates (interpolated from vertex shader) 
uniform sampler2D theTextureMap;
out vec4 FragColor;	// Color that will be used for the fragment
void main()
{
   FragColor = texture(theTextureMap,theTexCoord)*vec4(theColor, 1.0f);   // Multiply color and texture color
}
#endglsl